Struct Icr
#[repr(transparent)]pub struct Icr(pub u32);Expand description
GFXTIM interrupt clear register.
Tuple Fields
0: u32Implementations
impl Icr
impl Icr
pub const fn cafcof(&self) -> bool
pub const fn cafcof(&self) -> bool
clear absolute frame counter overflow flag This bit clears AFCOF in GXTIM_ISR.
pub const fn set_cafcof(&mut self, val: bool)
pub const fn set_cafcof(&mut self, val: bool)
clear absolute frame counter overflow flag This bit clears AFCOF in GXTIM_ISR.
pub const fn calcof(&self) -> bool
pub const fn calcof(&self) -> bool
clear absolute line counter overflow flag This bit clears ALCOF in GXTIM_ISR.
pub const fn set_calcof(&mut self, val: bool)
pub const fn set_calcof(&mut self, val: bool)
clear absolute line counter overflow flag This bit clears ALCOF in GXTIM_ISR.
pub const fn set_ctef(&mut self, val: bool)
pub const fn set_ctef(&mut self, val: bool)
clear tearing-effect flag This bit clears TEF in GXTIM_ISR.
pub const fn cafcc1f(&self) -> bool
pub const fn cafcc1f(&self) -> bool
clear absolute frame counter compare 1 flag This bit clears AFCC1F in GXTIM_ISR.
pub const fn set_cafcc1f(&mut self, val: bool)
pub const fn set_cafcc1f(&mut self, val: bool)
clear absolute frame counter compare 1 flag This bit clears AFCC1F in GXTIM_ISR.
pub const fn calcc1f(&self) -> bool
pub const fn calcc1f(&self) -> bool
clear absolute line counter compare 1 flag This bit clears ALCC1F in GXTIM_ISR.
pub const fn set_calcc1f(&mut self, val: bool)
pub const fn set_calcc1f(&mut self, val: bool)
clear absolute line counter compare 1 flag This bit clears ALCC1F in GXTIM_ISR.
pub const fn calcc2f(&self) -> bool
pub const fn calcc2f(&self) -> bool
clear absolute line counter compare 2 flag This bit clears ALCC2F in GXTIM_ISR.
pub const fn set_calcc2f(&mut self, val: bool)
pub const fn set_calcc2f(&mut self, val: bool)
clear absolute line counter compare 2 flag This bit clears ALCC2F in GXTIM_ISR.
pub const fn crfc1rf(&self) -> bool
pub const fn crfc1rf(&self) -> bool
clear relative frame counter 1 reload flag This bit clears RFC1RF in GXTIM_ISR.
pub const fn set_crfc1rf(&mut self, val: bool)
pub const fn set_crfc1rf(&mut self, val: bool)
clear relative frame counter 1 reload flag This bit clears RFC1RF in GXTIM_ISR.
pub const fn crfc2rf(&self) -> bool
pub const fn crfc2rf(&self) -> bool
clear relative frame counter 2 reload flag This bit clears RFC2RF in GXFXTIM_ISR.
pub const fn set_crfc2rf(&mut self, val: bool)
pub const fn set_crfc2rf(&mut self, val: bool)
clear relative frame counter 2 reload flag This bit clears RFC2RF in GXFXTIM_ISR.
pub const fn set_cwdgaf(&mut self, val: bool)
pub const fn set_cwdgaf(&mut self, val: bool)
clear watchdog alarm flag This bit clears WDGAF in GXFXTIM_ISR.
pub const fn cwdgpf(&self) -> bool
pub const fn cwdgpf(&self) -> bool
clear watchdog pre-alarm flag This bit clears WDGPF in GXFXTIM_ISR.
pub const fn set_cwdgpf(&mut self, val: bool)
pub const fn set_cwdgpf(&mut self, val: bool)
clear watchdog pre-alarm flag This bit clears WDGPF in GXFXTIM_ISR.